merkle_sigs implements Merkle signatures in Rust.
Structs
- Merkle
Public Key - A wrapper struct around a Lamport public key that implements Hashable.
- Proof
- An inclusion proof represent the fact that a
valueis a member of aMerkleTreewith root hashroot_hash, and hash functionalgorithm. - Public
Key - A one-time signing public key
Functions
- sign_
data_ vec - Signs the entries of the data vector
- verify_
data_ vec_ signature - Verifies the signature of the data. Returns an error if data couldn’t be verified.
Type Aliases
- Merkle
Signature - A type alias defining a Merkle signature. That includes both the Lamport leaf signature and inclusion proof.
- Merkle
Signed Data - A type alias defining Merkle signed data. That includes the data being signed along with the signature.